darkhistory.electrons.elec\_cooling
===================================

.. automodule:: darkhistory.electrons.elec_cooling

   
   .. rubric:: Functions

   .. autosummary::
      :toctree: elec_cooling
   
      get_elec_cooling_tf
   
   

   
   
   

   
   
   